globals [
  qual-index ;; evaluation-bias: it measures the gap between the optimal situation (= only best submission are published) and the current one.
  prod-loss ;; it measures how much productivity has been lost ( = resources invested for best submissions eventually unpublished) compared with the optimal situation.
  rev-prod-index ;; it measures the effort of referees ( = resource spent by referees for reviewing).
  system-productivity ;; sum of agent productivity
  system-productivity-aut ;; sum of authors' productivity.
  system-productivity-rev ;; sum of referees' productivity.
  career-gini-index ;;
  
  v ;; parameter v  expresses the quality gain velocity.
  
  overrating-factor
  underrating-factor
  ]

turtles-own [
  productivity ;; individual level of productivity
  career-position ;; ranking of agents per productivity
  expected-quality ;; expected quality of agent submission
  
  role ;; "author" or "reviewer" or "none"
  behaviour ;; "reliable" or "unreliable"
  
  ;; author's stuff:
  work-quality ;; quality of the author's work
  should-have-been-published ;; ideal publication based on work quality, before referees' evaluation
  boundary-value ;; set true if article quality is the median value
    
  evaluated-work-quality ;; work quality perceived by reviewer
  published ;; true or false if article is published
  submission-productivity-spent ;; productivity spent for submission 
  publication-productivity-gain ;; amount of productivity gained by publication
  
  last-time-as-author-got ;; "GOOD REVIEW" - "BAD REVIEW"
  
  ;; reviewer's stuff:
  evaluation-productivity-spent ;; productivity spent for reviewing
  ranking-delta ;; the difference between past evaluation and past real value of the submission. The smaller is, the better is.
  
  already-been-author ;; true or false

  ]             

to setup
  clear-all
  ask patches [set pcolor white]
  random-seed new-seed
  turtles-setup
  
  set v velocity
  
  set underrating-factor 1 - unreliable-excursion / 100
  set overrating-factor 1 + unreliable-excursion / 100
  
  ;; EXAMPLES RANDOM NORMAL
  ;show random-normal 10.0 0.0001
end

to turtles-setup
   if debug [type "Creating turtles:        "]
   create-turtles n-of-turtles [
    setxy (random-pxcor) (random-pycor)
    set color gray
    set shape "circle"
    set productivity initial-productivity
    set role "none"
    
    ifelse random 100 < unreliable-probability * 100
      [set behaviour "unreliable"]
      [set behaviour "reliable"]
    
    set label precision productivity 2
    set label-color black
    
    set already-been-author false
    
    if debug [type "."]
   ]
   if debug [print " OK."]
end


; end of setup part *********************************************************************


to go
  tick
  
  clear-links
  update-productivity
    
  ask turtles [set role "none"]
  
  set-reviewers
    
  set-authors

  match-actors
  
  authors-submit
  
  reviewers-evaluate
 
  select-publications
  
  rank-reviewers
  
  indexes
end

to update-productivity
  if debug [type "Increment productivity:  "]
  ask turtles [
    set published false
    set productivity productivity + round-productivity-gain + publication-productivity-gain - submission-productivity-spent - evaluation-productivity-spent
    
    set expected-quality (v * productivity) / (v * productivity + 1) ;; quality between 0 and 1
    
    set submission-productivity-spent 0
    set evaluation-productivity-spent 0
    set publication-productivity-gain 0
    set label precision productivity 2
    set color gray
    if debug [type "."]
    
    if plot-careers [
      set-current-plot "Careers"  
      create-temporary-plot-pen word "pen" who
      set-plot-pen-color who
      plot productivity
      ]
    ]
  
  ;; Career gini index
  let list1 [who] of turtles
  let list2 [who] of turtles
  let s 0
  foreach list1 [
    let temp [productivity] of turtle ?
    foreach list2 [
      set s s + abs(temp - [productivity] of turtle ?)
    ]
  ]   
  set career-gini-index s / (2 * (mean [productivity] of turtles) * (count turtles) ^ 2)
  
  set-current-plot "Career Gini"  
  set-current-plot-pen "default"
  plot career-gini-index
  ;; end career gini index
  
  ;; Career ranking
  let ordering 0;
  foreach sort-by [[productivity] of ?1 < [productivity] of ?2] turtles [
    ask ? [set career-position ordering]
    set ordering ordering + 1 
  ]
  if debug [print " OK."]
end

to set-authors
  if debug [type "Set authors:             "]
  let done 0
  while [done < n-of-turtles / 2] [
      ask one-of turtles with [role = "none"] [
        set role "author"
        set color violet
        set done done + 1 
        if debug [type "."]
      ]
    ]
  if debug [print " OK."]
end

to set-reviewers
  if debug [type "Set reviewers:           "]
  let done 0
  while [done < n-of-turtles / 2] [
      ask one-of turtles with [role = "none"] [
        set role "reviewer"
        
        if already-been-author = true
        [
          ifelse last-time-as-author-got = "GOOD REVIEW"
          [set behaviour "reliable"]
          [set behaviour "unreliable"]
        ]

        ifelse behaviour = "reliable"
        [set color red + 4]
        [set color red]
        set done done + 1
        if debug [type "."]
      ]
    ]
  if debug [print " OK."]
end

to match-actors
  if debug [type "Pairing agents:          "]
  ask turtles with [role = "author"] [
    create-link-with one-of other turtles with [role = "reviewer" and count my-links = 0]
    if debug [type "."]
    ]
  if debug [print " OK."]
end

to authors-submit
  ask turtles with [role = "author"] [
    
    ifelse already-been-author = true
    [
      ifelse last-time-as-author-got = "GOOD REVIEW"
      [
        set work-quality random-normal expected-quality (expected-quality * author-article-bias-factor)
        set submission-productivity-spent (productivity * author-spent-factor-for-article) ;; resources spent by an author to submit in percentage of his/her total amount of resources
      ]
      [
        set work-quality random-normal (expected-quality * bad-review-effect) (expected-quality * author-article-bias-factor)
        set submission-productivity-spent (productivity * bad-review-effect * author-spent-factor-for-article) ;; resources spent by an author to submit in percentage of his/her total amount of resources
      ]
    ]
    [
       set work-quality random-normal expected-quality (expected-quality * author-article-bias-factor)
       set submission-productivity-spent (productivity * author-spent-factor-for-article) ;; resources spent by an author to submit in percentage of his/her total amount of resources
    ]
    
    
    if debug [
        type "author submission with quality: "
        print work-quality
    ]
    
    set already-been-author true
    
    ]
end

  
to reviewers-evaluate
  ask links [
    
    let aut one-of both-ends with  [role = "author"]
    let author-p [productivity] of aut
    let work-q [work-quality] of aut
      
    let rev one-of both-ends with  [role = "reviewer"]
    let reviewer-p [productivity] of rev
    let reviewer-exp-q [expected-quality] of rev
    
    ifelse [behaviour] of rev = "reliable"
    [ 
      ;; reliable reviewer     
      ask rev [
        set evaluation-productivity-spent 0.5 * reviewer-p * (1 + (work-q - reviewer-exp-q))
        ]
      ask aut [
        let guess-author-productivity 0
        set guess-author-productivity random-normal author-p (author-p * reliable-evaluation-bias-factor)
        set evaluated-work-quality (v * guess-author-productivity) / (v * guess-author-productivity + 1) ;; estimate of the submission quality from the estimate of author's productivity with a normal variance curve = 10%
        ]
    ]
    
    [ 
      ;; unreliable reviewer  
      ask rev [
        set evaluation-productivity-spent 0.5 * reviewer-p * (1 + (work-q - reviewer-exp-q)) * unreliable-spent-factor-for-reviewing
        ]
      ask aut [
        let guess-author-productivity 0
        ifelse random 2 > 0
           [set guess-author-productivity random-normal (author-p * overrating-factor) (author-p * overrating-factor * reliable-evaluation-bias-factor)]
           [set guess-author-productivity random-normal (author-p * underrating-factor) (author-p * underrating-factor * reliable-evaluation-bias-factor)]
        if guess-author-productivity < 0 [set guess-author-productivity 0]
        set evaluated-work-quality (v * guess-author-productivity) / (v * guess-author-productivity + 1) ;; estimate of the submission quality from the estimate of author's productivity with a normal variance curve = 90%
        ]
    ]
    
    
    ask turtles with [role = "author"] [
      ifelse (abs work-quality - evaluated-work-quality) < good-review-max-error * work-quality
        [set last-time-as-author-got "GOOD REVIEW"]
        [set last-time-as-author-got "BAD REVIEW"]
    ]
    
    if debug [
        type "evaluating author work quality "
        type work-q
        type " by"
        ifelse [behaviour] of rev = "reliable" [type " a Reliable"] [type " an Unreliable"]
        type " reviewer with prod "
        type reviewer-p
        type " (exp qual "
        type reviewer-exp-q
        type "). Evaluated "
        ask aut [ type evaluated-work-quality]
        type " with an effort of "
        ask rev [ type evaluation-productivity-spent ]
        print "."
      ]
  ]
end

to select-publications
  ;; first 50% of articles publicated
  let i 0
  
  foreach sort-by [[evaluated-work-quality] of ?1 > [evaluated-work-quality] of ?2] turtles with [role = "author"] [
    ask ? [
    
      ifelse i < n-of-turtles / 2 * publication-factor [     
        set color yellow
        set published true
        ]
      [
        set published false
        ]
        
      set i i + 1
      ]
    ]
  
  let counter 0
  let limiter 0 ;; factor for the last author
  let maxfactor publication-productivity-gain-factor
  let count-publications n-of-turtles / 2 * publication-factor ;; n of publications
  foreach sort-by [[career-position] of ?1 < [career-position] of ?2] turtles with [role = "author" and published = true][
    set limiter (counter / (count-publications - 1))*(publication-productivity-gain-factor - 1)
    ask ? [
      set publication-productivity-gain productivity * (publication-productivity-gain-factor - limiter)
    ]
    set counter counter + 1
  ]
  
  ;; computing the ideal publication list:
  set i 0
  let median-value median [work-quality] of turtles with [role = "author"]  
  
  foreach sort-by [[work-quality] of ?1 > [work-quality] of ?2] turtles with [role = "author"] [
    ask ? [ 
      ifelse i < n-of-turtles / 2 * publication-factor [
        set should-have-been-published true
        ]
      [
        set should-have-been-published false
        ]  
      set i i + 1
      ]
    ]

    ask turtles with [role = "author"] [
      set boundary-value false;
    ]
    ask turtles with [role = "author" and work-quality = median-value] [
      set boundary-value true;
    ]

end

to rank-reviewers
  ask links [   
    let aut one-of both-ends with  [role = "author"]
    let work-q [work-quality] of aut
    let work-eval [evaluated-work-quality] of aut
      
    let rev one-of both-ends with  [role = "reviewer"]
    ask rev [set ranking-delta abs (work-q - work-eval)]
  ]
end

to indexes
  
  set system-productivity sum [productivity] of turtles
  set system-productivity-aut sum [productivity] of turtles with [role = "author"]
  set system-productivity-rev sum [productivity] of turtles with [role = "reviewer"] 
  set-current-plot "System Productivity"  
  set-current-plot-pen "total"
  plot system-productivity
  set-current-plot-pen "author"
  plot system-productivity-aut
  set-current-plot-pen "reviewer"
  plot system-productivity-rev
  
  if debug [print "******* RESULTS *******"]
  
  if debug [
  print "Published articles:"
  ask turtles with [role = "author" and published = true] [
      type "qual: \t"
      type work-quality;
      type "\t\teval: \t"
      type evaluated-work-quality;
      type "\t\tboundary: \t"
      type boundary-value
      type "\t\tgained: \t"
      print publication-productivity-gain;
    ]
  ]
  
  if debug [
  print "Unpublished articles:"
  ask turtles with [role = "author" and published = false] [
      type "qual: \t"
      type work-quality;
      type "\t\teval: \t"
      type evaluated-work-quality;
      type "\t\tboundary: \t"
      type boundary-value
      type "\t\tgained: \t"
      print publication-productivity-gain;
    ]
  ]
  
  if debug [ 
    type "Number of boundary cases: "
    print count turtles with [role = "author" and boundary-value = true ]
    type "Number of non-boundary cases: "
  ]
  let non-bound-cases-count count turtles with [role = "author" and boundary-value = false ]
  if debug [ print non-bound-cases-count ]
  
  if debug [ 
    print "Fair cases: "
    type "Number of published articles that should have been published: "
    print count turtles with [role = "author" and published = true and should-have-been-published = true and boundary-value = false ]
    type "Number of unpublished articles that should not have been published: "
    print count turtles with [role = "author" and published = false and should-have-been-published = false and boundary-value = false ]
  ]
  
  if debug [ 
    print "Unfair cases: "
    type "Number of unpublished articles that should have been published: "
  ]
  let unpub-errors count turtles with [role = "author" and published = false and should-have-been-published = true and boundary-value = false  ]
  if debug [ 
    print unpub-errors
    type "Number of published articles that should not have been published: "
    print count turtles with [role = "author" and published = true and should-have-been-published = false and boundary-value = false  ]
  ]
  
  if debug [print "******* STATS *******" ]
  
  if debug [type "Number of published articles: \t\t" ]
  let published-articles-count count turtles with [role = "author" and published = true ]
  if debug [print published-articles-count ]
  if debug [type "Number of unpublished articles: \t" ]
  let unpublished-articles-count count turtles with [role = "author" and published = false ]
  if debug [print unpublished-articles-count ]
  
  if debug [ print "*** Ideal solution ***" ]
  
  if debug [ type "Sum of ideal published qual: \t\t" ]
  let best-pub-qual sum [work-quality] of turtles with [role = "author" and should-have-been-published = true ]
  if debug [ 
    print best-pub-qual
    type "Sum of ideal unpublished qual: \t\t"
  ]
  let best-unpub-qual sum [work-quality] of turtles with [role = "author" and should-have-been-published = false ]
  if debug [ print best-unpub-qual ]
  
  if debug [ print "*** Peer review solution ***" ]
  
  if debug [ type "Sum of published qual: \t\t\t" ]
  let pub-qual sum [work-quality] of turtles with [role = "author" and published = true ]
  if debug [ print pub-qual ]
  if debug [ type "Sum of unpublished qual: \t\t" ]
  let unpub-qual sum [work-quality] of turtles with [role = "author" and published = false ]
  if debug [ 
    print unpub-qual
    print ""
    type "Mean quality of published articles: \t"
  ]
  let mean-published-quality mean [work-quality] of turtles with [role = "author" and published = true ]
  if debug [ 
    print mean-published-quality
    type "Mean quality of unpublished articles: \t"
  ]
  let mean-unpublished-quality mean [work-quality] of turtles with [role = "author" and published = false ]
  if debug [ 
    print mean-unpublished-quality
    type "Number of unpublished articles with quality higher than the mean of published ones: \t"
    print count turtles with [role = "author" and published = false and work-quality > mean-published-quality]
  ]
  
  
  if results [print "*** Indexes ***"]

  if results [type "Evaluation bias: \t\t\t"]
  set qual-index unpub-errors / published-articles-count * 100 ; % of number of published submissions
  if results [print qual-index]
  if results [type "Productivity loss: \t\t"]
  set prod-loss (best-pub-qual - pub-qual) / best-pub-qual * 100 ; % of total quality of ideal set of published submissions
  if results [print prod-loss]
  if results [type "Reviewing productivity index: \t"]
  ;; set rev-prod-index sum [evaluation-productivity-spent] of turtles with [role = "reviewer"] ; original
  let rev-spent sum [evaluation-productivity-spent] of turtles with [role = "reviewer"]
  let aut-spent sum [submission-productivity-spent] of turtles with [role = "author"]
  set rev-prod-index rev-spent / aut-spent * 100 ; percentage
  if results [print rev-prod-index]
  
  set-current-plot "Evaluation Bias"  
  set-current-plot-pen "errors"
  plot qual-index
  
  set-current-plot "Productivity Loss"  
  set-current-plot-pen "prodloss"
  plot prod-loss
  
  set-current-plot "Reviewing Productivity Index"  
  set-current-plot-pen "default"
  plot rev-prod-index
  
end

@#$#@#$#@
GRAPHICS-WINDOW
25
140
464
600
16
16
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks

SLIDER
25
85
197
118
n-of-turtles
n-of-turtles
2
200
200
2
1
NIL
HORIZONTAL

BUTTON
25
30
88
63
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
95
30
158
63
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
165
30
228
63
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

INPUTBOX
475
205
627
265
round-productivity-gain
1
1
0
Number

INPUTBOX
475
140
627
200
initial-productivity
0
1
0
Number

INPUTBOX
475
270
627
330
publication-factor
0.75
1
0
Number

TEXTBOX
635
275
785
331
Publication selection rate
11
0.0
1

TEXTBOX
635
210
785
251
Productivity gained by default in each round
11
0.0
1

INPUTBOX
475
335
627
395
publication-productivity-gain-factor
1.5
1
0
Number

TEXTBOX
635
360
785
386
Published authors' productivity gain
11
0.0
1

SWITCH
235
30
338
63
debug
debug
1
1
-1000

TEXTBOX
30
610
180
628
||| : author
11
115.0
1

TEXTBOX
95
610
245
628
||| : reviewer unreliable
11
15.0
1

TEXTBOX
330
610
480
628
||| : published
11
45.0
1

PLOT
805
275
1265
400
Productivity Loss
NIL
%
0.0
10.0
0.0
100.0
true
false
PENS
"default" 1.0 0 -16777216 true
"prodloss" 1.0 0 -955883 true

PLOT
805
145
1265
270
Evaluation Bias
NIL
%
0.0
10.0
0.0
100.0
true
false
PENS
"default" 1.0 0 -16777216 true
"errors" 1.0 0 -2674135 true

PLOT
805
665
1265
790
System Productivity
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"total" 1.0 0 -10899396 true
"author" 1.0 0 -8630108 true
"reviewer" 1.0 0 -2674135 true

PLOT
805
405
1265
530
Reviewing Productivity Index
NIL
NIL
0.0
10.0
0.0
100.0
true
false
PENS
"default" 1.0 0 -16777216 true

TEXTBOX
220
610
370
628
||| : reviewer reliable
11
19.0
1

SLIDER
475
400
625
433
unreliable-probability
unreliable-probability
0
1
0.5
0.01
1
NIL
HORIZONTAL

INPUTBOX
475
440
627
500
unreliable-spent-factor-for-reviewing
0.5
1
0
Number

TEXTBOX
635
440
785
496
Productivity multiplier spent by unreliable referees for reviewing
11
0.0
1

TEXTBOX
635
530
785
556
Underrating factor by unreliable referees
11
0.0
1

TEXTBOX
635
595
785
621
Overrating factor by unreliable referees
11
0.0
1

TEXTBOX
635
165
785
191
Initial productivity for all agents
11
0.0
1

SWITCH
345
30
448
63
results
results
1
1
-1000

SWITCH
455
30
577
63
plot-careers
plot-careers
1
1
-1000

PLOT
1270
145
1735
660
Careers
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

INPUTBOX
805
35
957
95
velocity
0.1
1
0
Number

INPUTBOX
960
35
1112
95
author-article-bias-factor
0.1
1
0
Number

INPUTBOX
1115
35
1332
95
author-spent-factor-for-article
1
1
0
Number

INPUTBOX
1335
35
1487
95
reliable-evaluation-bias-factor
0.1
1
0
Number

MONITOR
1305
170
1407
215
NIL
career-gini-index
17
1
11

PLOT
805
535
1265
660
Career Gini
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

SLIDER
475
560
647
593
unreliable-excursion
unreliable-excursion
10
90
90
10
1
NIL
HORIZONTAL

MONITOR
475
600
552
645
underrating
underrating-factor
2
1
11

MONITOR
560
600
627
645
overrating
overrating-factor
2
1
11

INPUTBOX
30
645
182
705
good-review-max-error
0.1
1
0
Number

INPUTBOX
35
715
187
775
bad-review-effect
0.1
1
0
Number

@#$#@#$#@
NOTE
----------------
This file runs the "Fair authors" scenario, where were assumed that in case of a pertinent referee evaluation received when authors, agents reinforced their confidence on the good quality of the evaluation process and continued to invest everything to send good quality submissions irrespectively of the fate of their submission. In case of non-pertinent evaluation, they invested less in the subsequent round (i.e., only the 10% of their resources) and accumulate resources for the subsequent round irrespectively of their previous publication.

CREDITS AND REFERENCES
----------------------
Squazzoni F. and Gandelli C. (2012) Opening the Black-Box of Referee Behaviour. An Agent-Based Model of Peer Review. Forthcoming in... For any contact, please write to squazzon@eco.unibs.it
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="scenario3 - probability distribution" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="unreliable-probability" first="0" step="0.25" last="1"/>
    <steppedValueSet variable="unreliable-spent-factor-for-reviewing" first="0.5" step="0.25" last="1"/>
    <enumeratedValueSet variable="underrating-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="overrating-factor">
      <value value="1.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="paper-1" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="1"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.1"/>
      <value value="1.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="unreliable-probability" first="0" step="0.25" last="1"/>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="underrating-factor">
      <value value="0.5"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="overrating-factor">
      <value value="1.5"/>
      <value value="1.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-behaviour">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="gini-time" repetitions="5" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="underrating-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="overrating-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-behaviour">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="paper-1-moreruns" repetitions="1000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="unreliable-probability" first="0" step="0.25" last="1"/>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="underrating-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="overrating-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-behaviour">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="paper-1-moreruns(last)" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="unreliable-probability" first="0" step="0.25" last="1"/>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="underrating-factor">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="overrating-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-behaviour">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="54000 runs" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="unreliable-probability" first="0" step="0.25" last="1"/>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-excursion">
      <value value="10"/>
      <value value="10"/>
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choose-reviewers-by-ranking">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-behaviour">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="confronto tra versioni" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>qual-index</metric>
    <metric>prod-loss</metric>
    <metric>rev-prod-index</metric>
    <metric>system-productivity</metric>
    <metric>system-productivity-aut</metric>
    <metric>system-productivity-rev</metric>
    <metric>career-gini-index</metric>
    <enumeratedValueSet variable="n-of-turtles">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-productivity">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-productivity-gain">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-factor">
      <value value="0.25"/>
      <value value="0.5"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-productivity-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-spent-factor-for-reviewing">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-excursion">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-article-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="debug">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="results">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plot-careers">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="versione-flaminio">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="good-review-max-error">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-review-effect">
      <value value="0.1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
